// Load the data from the CSV file
d3.csv('data.csv', (d) => {
  return { year: d.year, deathcases: +d.deathcases };
}).then((data) => {
  // Line chart dimensions
  const width = 960;
  const height = 400;
  const margin = {
    top: 20,
    right: 20,
    bottom: 50,
    left: 50,
  };
  const chartWidth =
    width - margin.left - margin.right;
  const chartHeight =
    height - margin.top - margin.bottom;

  // Create the X and Y scales
  const x_axis = d3
    .scaleBand()
    .range([0, chartWidth])
    .padding(0.5)
    .domain(data.map((d) => d.year));

  const y_axis = d3
    .scaleLinear()
    .range([chartHeight, 0])
    .domain([0, d3.max(data, (d) => d.deathcases)]);

  // Create the SVG element
  const svg = d3
    .select('#chart')
    .append('svg')
    .attr('width', width)
    .attr('height', height)
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`
    );

  // Add the X axis
  svg
    .append('g')
    .attr(
      'transform',
      `translate(0,${chartHeight})`
    )
    .call(d3.axisBottom(x_axis));

  // Add the Y axis
  svg.append('g').call(d3.axisLeft(y_axis));

  // Add the line chart
  svg
    .append('path')
    .datum(data)
    .attr('fill', 'none')
    .attr('stroke', 'green')
    .attr('stroke-width', 6)
    .attr(
      'd',
      d3
        .line()
        .x((d) => x_axis(d.year) + x_axis.bandwidth() / 2)
        .y((d) => y_axis(d.deathcases))
    );

  // Add the X label
  svg
    .append('text')
    .attr(
      'transform',
      `translate(${chartWidth / 2},${chartHeight + margin.top + 30})`
    )
    .style('text-anchor', 'middle')
    .text('Year');

  // Add the Y label
  svg
    .append('text')
    .attr(
      'transform',
      `rotate(-90) translate(${-chartHeight / 2}, ${-margin.left + 20})`
    )
    .style('text-anchor', 'middle')
    .text('deathcases');
});
